package com.xinda.iot.service;

import java.util.List;

import com.xinda.common.core.domain.AjaxResult;
import com.xinda.iot.domain.Doc;
import org.springframework.web.multipart.MultipartFile;

/**
 * 档案管理Service接口
 * 
 * @author leo
 * @date 2025-04-04
 */
public interface IDocService 
{
    /**
     * 查询档案管理
     * 
     * @param id 档案管理主键
     * @return 档案管理
     */
    public Doc selectDocById(Long id);

    /**
     * 查询档案管理列表
     * 
     * @param doc 档案管理
     * @return 档案管理集合
     */
    public List<Doc> selectDocList(Doc doc);

    /**
     * 新增档案管理
     * 
     * @param doc 档案管理
     * @return 结果
     */
    public int insertDoc(Doc doc);

    /**
     * 修改档案管理
     * 
     * @param doc 档案管理
     * @return 结果
     */
    public int updateDoc(Doc doc);

    /**
     * 批量删除档案管理
     * 
     * @param ids 需要删除的档案管理主键集合
     * @return 结果
     */
    public int deleteDocByIds(Long[] ids);

    /**
     * 删除档案管理信息
     * 
     * @param id 档案管理主键
     * @return 结果
     */
    public int deleteDocById(Long id);

}
